@@ -1,19 +1,24 @@
 package Firewall::DBI::Oracle;
 
-use 5.018;
+#------------------------------------------------------------------------------
+# 加载扩展模块
+#------------------------------------------------------------------------------
 use Moose;
 use namespace::autoclean;
 use DBIx::Custom;
 use Carp;
 
+#------------------------------------------------------------------------------
+# 继承 Firewall::DBI::Role 方法属性
+#------------------------------------------------------------------------------
+with 'Firewall::DBI::Role';
+
 has option => (
   is      => 'ro',
   isa     => 'Undef | HashRef[Str]',
   default => undef,
 );
 
-with 'Firewall::DBI::Role';
-
 has '+dbi' => (
   isa     => 'DBIx::Custom',
   handles => qr/^(?:select|update|insert|delete|execute|user).*/,
@@ -30,7 +35,7 @@ for my $func (qw( execute delete update insert batchExecute )) {
       $self->dbi->dbh->commit;
     };
 
-    if ($@) {
+    if (!!$@) {
       # confess "ERROR: $@";
       if ( $self->dbi->dbh->rollback ) {
         confess "ERROR: $@";
