@@ -1,12 +1,17 @@
 package Firewall::DBI::Pg;
 # ABSTRACT: turns baubles into trinkets
 
-use 5.018;
-use Carp;
+#------------------------------------------------------------------------------
+# 加载扩展模块
+#------------------------------------------------------------------------------
 use Moose;
 use namespace::autoclean;
+use Carp;
 use DBIx::Custom;
 
+#------------------------------------------------------------------------------
+# 继承 Firewall::DBI::Role 方法属性
+#------------------------------------------------------------------------------
 with 'Firewall::DBI::Role';
 
 has option => (
@@ -29,7 +34,7 @@ for my $func (qw( execute delete update insert batchExecute )) {
       $result = $self->$orig(@_);
       $self->dbi->dbh->commit;
     };
-    if ($@) {
+    if (!!$@) {
       if ( $self->dbi->dbh->rollback ) {
         confess "ERROR: $@";
       }
