@@ -1,9 +1,10 @@
 package Firewall::DBI::Role;
 
-use 5.018;
+#------------------------------------------------------------------------------
+# 加载扩展模块
+#------------------------------------------------------------------------------
 use Carp;
 use Moose::Role;
-use Mojo::Util qw(dumper);
 
 has dsn => (
   is       => 'ro',
@@ -29,6 +30,9 @@ has dbi => (
   builder => '_buildDbi',
 );
 
+#------------------------------------------------------------------------------
+# 继承该角色必须实现的方法
+#------------------------------------------------------------------------------
 requires 'clone';
 requires 'batchExecute';
 
