@@ -1,11 +1,12 @@
-#!/usr/bin/perlnew
+#!/usr/bin/env perl
 use strict;
 use warnings;
-use 5.014;
-use Data::Dumper;
+use utf8;
+use 5.018;
+use Mojo::Util qw(dumper);
 use DBI;
- 
+
 my @driver_names = DBI->available_drivers;
 my %drivers      = DBI->installed_drivers;
-say Dumper \@driver_names;
-say Dumper \%drivers;
+say dumper \@driver_names;
+say dumper \%drivers;
